==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/et/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Kinnita kahendite hulgi kustutamine',
  'bulk_delete_help'	=> 'Kontrolli alltoodud vahendid hulgi kustutamiseks. Kui oled need kustutanud, võib neid veel taastada, kuid neid ei saa enam seostada kasutajatega, kellega nad hetkel seotud on.',
  'bulk_delete_warn'	=> 'Sa hakkad kustsutama :asset_count vahendit.',
	'bulk_update'		=> 'Uuenduste hulgihaldus',
	'bulk_update_help'	=> 'See vorm võimaldab teil korraga mitme vara värskendada. Täitke ainult väljad, mida tuleb muuta. Kõik tühjad tühikud jäävad muutmata.',
	'bulk_update_warn'	=> 'Olete muutma vara omaduste omadust: asset_count.',
    'checkedout_to'		=> 'Välja antud',
    'checkout_date'		=> 'Checkout Date',
    'checkin_date'		=> 'Checkin Kuupäev',
    'checkout_to'		=> 'Checkout kuni',
    'cost'				=> 'Ostuhind',
    'create'			=> 'Loo vahend',
    'date'				=> 'Ostu kuupäev',
    'depreciation'	    => 'Amortisatsioon',
    'depreciates_on'	=> 'Halvustab sisse',
    'default_location'	=> 'Vaikimisi asukoht',
    'eol_date'			=> 'EOL Kuupäev',
    'eol_rate'			=> 'EOL määr',
    'expected_checkin'  => 'Ootel Checkin Kuupäev',
    'expires'			=> 'Aegub',
    'fully_depreciated'	=> 'Täielikult amortiseerunud',
    'help_checkout'		=> 'Kui soovite selle vara koheselt määrata, valige ülaltoodud olekute loendist "Valmis kasutusele võtmine".',
    'mac_address'		=> 'MAC aadress',
    'manufacturer'		=> 'Tootja',
    'model'				=> 'Mudel',
    'months'			=> 'kuud',
    'name'				=> 'Ressursi nimi',
    'notes'				=> 'Märkmed',
    'order'				=> 'Tellimuse number',
    'qr'				=> 'QR kood',
    'requestable'		=> 'Kasutajad võivad seda vara taotleda',
    'select_statustype'	=> 'Valige oleku tüüp',
    'serial'			=> 'Seerianumber',
    'status'			=> 'Staatus',
    'tag'				=> 'Varade silt',
    'update'			=> 'Varade värskendamine',
    'warranty'			=> 'Garantii',
		'warranty_expires'		=> 'Garantii aegub',
    'years'				=> 'aastat',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/et/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Kinnita kahendite hulgi kustutamine',
  'bulk_delete_help'	=> 'Kontrolli alltoodud vahendid hulgi kustutamiseks. Kui oled need kustutanud, võib neid veel taastada, kuid neid ei saa enam seostada kasutajatega, kellega nad hetkel seotud on.',
  'bulk_delete_warn'	=> 'Sa hakkad kustsutama :asset_count vahendit.',
    'bulk_update'		=> 'Uuenduste hulgihaldus',
    'bulk_update_help'	=> 'See vorm võimaldab teil korraga mitme vara värskendada. Täitke ainult väljad, mida tuleb muuta. Kõik tühjad tühikud jäävad muutmata.',
    'bulk_update_warn'	=> 'Olete muutma vara omaduste omadust: asset_count.',
    'checkedout_to'		=> 'Välja antud',
    'checkout_date'		=> 'Checkout Date',
    'checkin_date'		=> 'Checkin Kuupäev',
    'checkout_to'		=> 'Checkout kuni',
    'cost'				=> 'Ostuhind',
    'create'			=> 'Loo vahend',
    'date'				=> 'Ostu kuupäev',
    'depreciation'	    => 'Amortisatsioon',
    'depreciates_on'	=> 'Halvustab sisse',
    'default_location'	=> 'Vaikimisi asukoht',
    'eol_date'			=> 'EOL Kuupäev',
    'eol_rate'			=> 'EOL määr',
    'expected_checkin'  => 'Ootel Checkin Kuupäev',
    'expires'			=> 'Aegub',
    'fully_depreciated'	=> 'Täielikult amortiseerunud',
    'help_checkout'		=> 'Kui soovite selle vara koheselt määrata, valige ülaltoodud olekute loendist "Valmis kasutusele võtmine".',
    'mac_address'		=> 'MAC aadress',
    'manufacturer'		=> 'Tootja',
    'model'				=> 'Mudel',
    'months'			=> 'kuud',
    'name'				=> 'Ressursi nimi',
    'notes'				=> 'Märkmed',
    'order'				=> 'Tellimuse number',
    'qr'				=> 'QR kood',
    'requestable'		=> 'Kasutajad võivad seda vara taotleda',
    'select_statustype'	=> 'Valige oleku tüüp',
    'serial'			=> 'Seerianumber',
    'status'			=> 'Staatus',
    'tag'				=> 'Varade silt',
    'update'			=> 'Varade värskendamine',
    'warranty'			=> 'Garantii',
        'warranty_expires'		=> 'Garantii aegub',
    'years'				=> 'aastat',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
